lidarwind.filters.WindCubeCloudRemoval
======================================

.. currentmodule:: lidarwind.filters

.. autoclass:: WindCubeCloudRemoval

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~WindCubeCloudRemoval.__init__
      ~WindCubeCloudRemoval.get_height_interface
      ~WindCubeCloudRemoval.get_interp_interf_height
      ~WindCubeCloudRemoval.get_noise_free_beta
      ~WindCubeCloudRemoval.remove_cloud
   
   

   
   
   